--- check_nt.c.orig	2003-12-04 16:41:08.000000000 +1000
+++ check_nt.c	2003-12-04 16:46:21.000000000 +1000
@@ -26,6 +26,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Version history:
+ *
+ * 1.7.2.3: Yves Rubin - Original version
+ *
+ * 1.7.2.4: Greg Vickers, 03/12/03 - Added the ability to check free space
+ *          against Mb rather than used space against percentage value.
+ *          Implemented this via command line option -m or --mb.
+ *
  *****************************************************************************/
 
 #include "config.h"
@@ -60,6 +68,7 @@
 int check_critical_value=FALSE;
 int vars_to_check=CHECK_NONE;
 int show_all=FALSE;
+int disk_space_in_mb=FALSE;
 
 const char *progname = "check_nt";
 
@@ -204,12 +213,22 @@
 				total_disk_space=atof(strtok(NULL,"&"));
 				percent_used_space = ((total_disk_space - free_disk_space) / total_disk_space) * 100;
 
-				if (free_disk_space>=0) {
+				if (free_disk_space>=0 && disk_space_in_mb==TRUE) {
+					asprintf(&temp_string,"%s:\\ - total: %.2f Mb - used: %.2f Mb - free %.2f Mb",
+							value_list, total_disk_space / 1048576, (total_disk_space - free_disk_space) / 1048576, free_disk_space / 1048576); 
+					if(check_critical_value==TRUE && (free_disk_space / 1048576) <= critical_value)
+						return_code=STATE_CRITICAL;
+					else if (check_warning_value==TRUE && (free_disk_space / 1048576) <= warning_value)
+						return_code=STATE_WARNING;	
+					else
+						return_code=STATE_OK;	
+					asprintf(&output_message,"%s",temp_string);
+
+				}
+				else if (free_disk_space>=0) {
 					asprintf(&temp_string,"%s:\\ - total: %.2f Gb - used: %.2f Gb (%.0f%%) - free %.2f Gb (%.0f%%)",
 							value_list, total_disk_space / 1073741824, (total_disk_space - free_disk_space) / 1073741824, percent_used_space,
 							 free_disk_space / 1073741824, (free_disk_space / total_disk_space)*100); 
-
-
 					if(check_critical_value==TRUE && percent_used_space >= critical_value)
 						return_code=STATE_CRITICAL;
 					else if (check_warning_value==TRUE && percent_used_space >= warning_value)
@@ -398,6 +417,7 @@
 		{"hostname", required_argument,0,'H'},
 		{"version",  no_argument,      0,'V'},
 		{"help",     no_argument,      0,'h'},
+		{"mb",       no_argument,      0,'m'},
 		{0,0,0,0}
 	};
 #endif
@@ -424,9 +444,9 @@
 
 	while (1){
 #ifdef HAVE_GETOPT_H
-		c = getopt_long(argc,argv,"+hVH:t:c:w:p:v:l:s:d:",long_options,&option_index);
+		c = getopt_long(argc,argv,"+hVmH:t:c:w:p:v:l:s:d:",long_options,&option_index);
 #else
-		c = getopt(argc,argv,"+hVH:t:c:w:p:v:l:s:d:");
+		c = getopt(argc,argv,"+hVmH:t:c:w:p:v:l:s:d:");
 #endif
 
 		if (c==-1||c==EOF||c==1)
@@ -500,6 +520,9 @@
 				socket_timeout=atoi(optarg);
 				if(socket_timeout<=0)
 					return ERROR;
+				break;
+			case 'm': /* test USEDDISKSPACE on Gb rather than percentage */
+				disk_space_in_mb = TRUE;
 			}
 
 	}
@@ -519,7 +542,7 @@
 
 void print_help(void)
 {
-	print_revision(progname,"$Revision: 1.7.2.3 $");
+	print_revision(progname,"$Revision: 1.7.2.4 $");
 	printf
 		("Copyright (c) 2000 Yves Rubin (rubiyz@yahoo.com)\n\n"
 		 "This plugin attempts to contact the NSClient service running on a Windows NT/2000/XP server to\n"
@@ -542,6 +565,7 @@
 		 "      UPTIME = Get the uptime of the machine. No specific parameters. No warning or critical threshold\n"
 		 "      USEDDISKSPACE = Size and percentage of disk use. Request a -l parameter containing the drive letter only.\n"
 		 "                      Warning and critical thresholds can be specified with -w and -c.\n"
+		 "                      Use -m to specify threshold values in Mb. These value are checked against free disk space.\n"
 		 "      MEMUSE = Memory use. Warning and critical thresholds can be specified with -w and -c.\n" 
 		 "      SERVICESTATE = Check the state of one or several services. Request a -l parameters with the following syntax:\n"
 		 "        -l <service1>,<service2>,<service3>,... You can specify -d SHOWALL in case you want to see working services\n"
